nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Dccparams

Struct Dccparams 

#[repr(transparent)]
pub struct Dccparams(pub u32);
Device Controller Capability Parameters

Tuple Fields

0: u32

Implementations

Source

impl Dccparams

pub const fn den(&self) -> u8

Device Endpoint Number This field indicates the number of endpoints built into the device controller

pub const fn set_den(&mut self, val: u8)

Device Endpoint Number This field indicates the number of endpoints built into the device controller

pub const fn dc(&self) -> bool

Device Capable When this bit is 1, this controller is capable of operating as a USB 2.0 device.

pub const fn set_dc(&mut self, val: bool)

Device Capable When this bit is 1, this controller is capable of operating as a USB 2.0 device.

pub const fn hc(&self) -> bool

Host Capable When this bit is 1, this controller is capable of operating as an EHCI compatible USB 2

pub const fn set_hc(&mut self, val: bool)

Host Capable When this bit is 1, this controller is capable of operating as an EHCI compatible USB 2