nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Gptimer1ld

Struct Gptimer1ld 

#[repr(transparent)]
pub struct Gptimer1ld(pub u32);
General Purpose Timer #1 Load

Tuple Fields

0: u32

Implementations

Source

impl Gptimer1ld

pub const fn gptld(&self) -> u32

General Purpose Timer Load Value These bit fields are loaded to GPTCNT bits when GPTRST bit is set ‘1b’

pub const fn set_gptld(&mut self, val: u32)

General Purpose Timer Load Value These bit fields are loaded to GPTCNT bits when GPTRST bit is set ‘1b’