nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Hwhost

Struct Hwhost 

#[repr(transparent)]
pub struct Hwhost(pub u32);
Host Hardware Parameters

Tuple Fields

0: u32

Implementations

Source

impl Hwhost

pub const fn hc(&self) -> Hc

Host Capable. Indicating whether host operation mode is supported or not.

pub const fn set_hc(&mut self, val: Hc)

Host Capable. Indicating whether host operation mode is supported or not.

pub const fn nport(&self) -> u8

The Nmber of downstream ports supported by the host controller is (NPORT+1)

pub const fn set_nport(&mut self, val: u8)

The Nmber of downstream ports supported by the host controller is (NPORT+1)