#[repr(transparent)]pub struct Otgsc(pub u32);Expand description
On-The-Go Status & control
Tuple Fields
0: u32Implementations
Sourceimpl Otgsc
impl Otgsc
Sourcepub const fn vd(&self) -> bool
pub const fn vd(&self) -> bool
VBUS_Discharge - Read/Write. Setting this bit causes VBus to discharge through a resistor.
Sourcepub const fn set_vd(&mut self, val: bool)
pub const fn set_vd(&mut self, val: bool)
VBUS_Discharge - Read/Write. Setting this bit causes VBus to discharge through a resistor.
Sourcepub const fn idpu(&self) -> bool
pub const fn idpu(&self) -> bool
ID Pullup - Read/Write This bit provide control over the ID pull-up resistor; 0 = off, 1 = on [default]
Sourcepub const fn set_idpu(&mut self, val: bool)
pub const fn set_idpu(&mut self, val: bool)
ID Pullup - Read/Write This bit provide control over the ID pull-up resistor; 0 = off, 1 = on [default]
Sourcepub const fn avv(&self) -> bool
pub const fn avv(&self) -> bool
A VBus Valid - Read Only. Indicates VBus is above the A VBus valid threshold.
Sourcepub const fn set_avv(&mut self, val: bool)
pub const fn set_avv(&mut self, val: bool)
A VBus Valid - Read Only. Indicates VBus is above the A VBus valid threshold.
Sourcepub const fn asv(&self) -> bool
pub const fn asv(&self) -> bool
A Session Valid - Read Only. Indicates VBus is above the A session valid threshold.
Sourcepub const fn set_asv(&mut self, val: bool)
pub const fn set_asv(&mut self, val: bool)
A Session Valid - Read Only. Indicates VBus is above the A session valid threshold.
Sourcepub const fn bsv(&self) -> bool
pub const fn bsv(&self) -> bool
B Session Valid - Read Only. Indicates VBus is above the B session valid threshold.
Sourcepub const fn set_bsv(&mut self, val: bool)
pub const fn set_bsv(&mut self, val: bool)
B Session Valid - Read Only. Indicates VBus is above the B session valid threshold.
Sourcepub const fn bse(&self) -> bool
pub const fn bse(&self) -> bool
B Session End - Read Only. Indicates VBus is below the B session end threshold.
Sourcepub const fn set_bse(&mut self, val: bool)
pub const fn set_bse(&mut self, val: bool)
B Session End - Read Only. Indicates VBus is below the B session end threshold.
Sourcepub const fn tog_1ms(&self) -> bool
pub const fn tog_1ms(&self) -> bool
1 millisecond timer toggle - Read Only. This bit toggles once per millisecond.
Sourcepub const fn set_tog_1ms(&mut self, val: bool)
pub const fn set_tog_1ms(&mut self, val: bool)
1 millisecond timer toggle - Read Only. This bit toggles once per millisecond.
Sourcepub const fn set_avvis(&mut self, val: bool)
pub const fn set_avvis(&mut self, val: bool)
A VBus Valid Interrupt Status - Read/Write to Clear
Sourcepub const fn set_asvis(&mut self, val: bool)
pub const fn set_asvis(&mut self, val: bool)
A Session Valid Interrupt Status - Read/Write to Clear
Sourcepub const fn set_bsvis(&mut self, val: bool)
pub const fn set_bsvis(&mut self, val: bool)
B Session Valid Interrupt Status - Read/Write to Clear
Sourcepub const fn set_bseis(&mut self, val: bool)
pub const fn set_bseis(&mut self, val: bool)
B Session End Interrupt Status - Read/Write to Clear
Sourcepub const fn status_1ms(&self) -> bool
pub const fn status_1ms(&self) -> bool
1 millisecond timer Interrupt Status - Read/Write to Clear
Sourcepub const fn set_status_1ms(&mut self, val: bool)
pub const fn set_status_1ms(&mut self, val: bool)
1 millisecond timer Interrupt Status - Read/Write to Clear
Sourcepub const fn idie(&self) -> bool
pub const fn idie(&self) -> bool
USB ID Interrupt Enable - Read/Write. Setting this bit enables the USB ID interrupt.
Sourcepub const fn set_idie(&mut self, val: bool)
pub const fn set_idie(&mut self, val: bool)
USB ID Interrupt Enable - Read/Write. Setting this bit enables the USB ID interrupt.
Sourcepub const fn avvie(&self) -> bool
pub const fn avvie(&self) -> bool
A VBus Valid Interrupt Enable - Read/Write. Setting this bit enables the A VBus valid interrupt.
Sourcepub const fn set_avvie(&mut self, val: bool)
pub const fn set_avvie(&mut self, val: bool)
A VBus Valid Interrupt Enable - Read/Write. Setting this bit enables the A VBus valid interrupt.
Sourcepub const fn bseie(&self) -> bool
pub const fn bseie(&self) -> bool
B Session End Interrupt Enable - Read/Write. Setting this bit enables the B session end interrupt.
Sourcepub const fn set_bseie(&mut self, val: bool)
pub const fn set_bseie(&mut self, val: bool)
B Session End Interrupt Enable - Read/Write. Setting this bit enables the B session end interrupt.
Sourcepub const fn set_en_1ms(&mut self, val: bool)
pub const fn set_en_1ms(&mut self, val: bool)
1 millisecond timer Interrupt Enable - Read/Write