nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Portsc1

Struct Portsc1 

#[repr(transparent)]
pub struct Portsc1(pub u32);
Port Status & Control

Tuple Fields

0: u32

Implementations

Source

impl Portsc1

pub const fn ccs(&self) -> bool

Current Connect Status-Read Only

pub const fn set_ccs(&mut self, val: bool)

Current Connect Status-Read Only

pub const fn csc(&self) -> bool

Connect Status Change-R/WC

pub const fn set_csc(&mut self, val: bool)

Connect Status Change-R/WC

pub const fn pe(&self) -> bool

Port Enabled/Disabled-Read/Write

pub const fn set_pe(&mut self, val: bool)

Port Enabled/Disabled-Read/Write

pub const fn pec(&self) -> bool

Port Enable/Disable Change-R/WC

pub const fn set_pec(&mut self, val: bool)

Port Enable/Disable Change-R/WC

pub const fn oca(&self) -> Oca

Over-current Active-Read Only

pub const fn set_oca(&mut self, val: Oca)

Over-current Active-Read Only

pub const fn occ(&self) -> bool

Over-current Change-R/WC

pub const fn set_occ(&mut self, val: bool)

Over-current Change-R/WC

pub const fn fpr(&self) -> bool

Force Port Resume -Read/Write

pub const fn set_fpr(&mut self, val: bool)

Force Port Resume -Read/Write

pub const fn susp(&self) -> bool

Suspend - Read/Write or Read Only

pub const fn set_susp(&mut self, val: bool)

Suspend - Read/Write or Read Only

pub const fn pr(&self) -> bool

Port Reset - Read/Write or Read Only

pub const fn set_pr(&mut self, val: bool)

Port Reset - Read/Write or Read Only

pub const fn hsp(&self) -> bool

High-Speed Port - Read Only

pub const fn set_hsp(&mut self, val: bool)

High-Speed Port - Read Only

pub const fn ls(&self) -> Ls

Line Status-Read Only

pub const fn set_ls(&mut self, val: Ls)

Line Status-Read Only

pub const fn pp(&self) -> bool

Port Power (PP)-Read/Write or Read Only

pub const fn set_pp(&mut self, val: bool)

Port Power (PP)-Read/Write or Read Only

pub const fn po(&self) -> bool

Port Owner-Read/Write

pub const fn set_po(&mut self, val: bool)

Port Owner-Read/Write

pub const fn pic(&self) -> Pic

Port Indicator Control - Read/Write

pub const fn set_pic(&mut self, val: Pic)

Port Indicator Control - Read/Write

pub const fn ptc(&self) -> Ptc

Port Test Control - Read/Write

pub const fn set_ptc(&mut self, val: Ptc)

Port Test Control - Read/Write

pub const fn wkcn(&self) -> bool

Wake on Connect Enable (WKCNNT_E) - Read/Write

pub const fn set_wkcn(&mut self, val: bool)

Wake on Connect Enable (WKCNNT_E) - Read/Write

pub const fn wkdc(&self) -> bool

Wake on Disconnect Enable (WKDSCNNT_E) - Read/Write

pub const fn set_wkdc(&mut self, val: bool)

Wake on Disconnect Enable (WKDSCNNT_E) - Read/Write

pub const fn wkoc(&self) -> bool

Wake on Over-current Enable (WKOC_E) - Read/Write

pub const fn set_wkoc(&mut self, val: bool)

Wake on Over-current Enable (WKOC_E) - Read/Write

pub const fn phcd(&self) -> Phcd

PHY Low Power Suspend - Clock Disable (PLPSCD) - Read/Write

pub const fn set_phcd(&mut self, val: Phcd)

PHY Low Power Suspend - Clock Disable (PLPSCD) - Read/Write

pub const fn pfsc(&self) -> Pfsc

Port Force Full Speed Connect - Read/Write

pub const fn set_pfsc(&mut self, val: Pfsc)

Port Force Full Speed Connect - Read/Write

pub const fn pts_2(&self) -> bool

See description at bits 31-30

pub const fn set_pts_2(&mut self, val: bool)

See description at bits 31-30

pub const fn pspd(&self) -> Pspd

Port Speed - Read Only. This register field indicates the speed at which the port is operating.

pub const fn set_pspd(&mut self, val: Pspd)

Port Speed - Read Only. This register field indicates the speed at which the port is operating.

pub const fn ptw(&self) -> Ptw

Parallel Transceiver Width This bit has no effect if serial interface engine is used

pub const fn set_ptw(&mut self, val: Ptw)

Parallel Transceiver Width This bit has no effect if serial interface engine is used

pub const fn sts(&self) -> bool

Serial Transceiver Select 1 Serial Interface Engine is selected 0 Parallel Interface signals is selected Serial Interface Engine can be used in combination with UTMI+/ULPI physical interface to provide FS/LS signaling instead of the parallel interface signals

pub const fn set_sts(&mut self, val: bool)

Serial Transceiver Select 1 Serial Interface Engine is selected 0 Parallel Interface signals is selected Serial Interface Engine can be used in combination with UTMI+/ULPI physical interface to provide FS/LS signaling instead of the parallel interface signals

pub const fn pts_1(&self) -> u8

All USB port interface modes are listed in this field description, but not all are supported

pub const fn set_pts_1(&mut self, val: u8)

All USB port interface modes are listed in this field description, but not all are supported