nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Sbuscfg

Struct Sbuscfg 

#[repr(transparent)]
pub struct Sbuscfg(pub u32);
System Bus Config

Tuple Fields

0: u32

Implementations

Source

impl Sbuscfg

pub const fn ahbbrst(&self) -> Ahbbrst

AHB master interface Burst configuration These bits control AHB master transfer type sequence (or priority)

pub const fn set_ahbbrst(&mut self, val: Ahbbrst)

AHB master interface Burst configuration These bits control AHB master transfer type sequence (or priority)